import React from 'react';
import { Input, Button, Form, Select, Upload, Icon, Spin, message, InputNumber, Modal } from 'antd';
import './person.less';
import ajax from 'jquery/src/ajax/xhr.js'
import $ from 'jquery/src/ajax';

import { addressInit, splitUrl, } from '../../tools.js';
import { edulvlArr, zizhiArr, schoolArr } from '../../dataDic.js';


function getBase64(img, callback) {
    const reader = new FileReader();
    reader.addEventListener('load', () => callback(reader.result));
    reader.readAsDataURL(img);
};

function beforeUpload(file) {
    const isJPG = file.type === 'image/jpeg';
    if (!isJPG) {
        message.error('You can only upload JPG file!');
    }
    const isLt2M = file.size / 1024 / 1024 < 2;
    if (!isLt2M) {
        message.error('Image must smaller than 2MB!');
    }
    return isJPG && isLt2M;
};

class Avatar extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            imageUrl: ''
        }
    }
    handleChange(info) {
        if (info.file.status === 'done') {
            // Get this url from response in real world.
            getBase64(info.file.originFileObj, imageUrl => this.setState({ imageUrl }));
            this.props.urlData(info.file.response.data);
        }
    }
    render() {
        const imageUrl = this.state.imageUrl;
        return (
            <Upload
                className="avatar-uploader"
                name="avatar"
                showUploadList={false}
                action={globalConfig.context + "/api/user/avatar/uploadReplace"}
                data={{ 'sign': this.props.name }}
                beforeUpload={beforeUpload}
                onChange={this.handleChange.bind(this)}
            >
                {
                    imageUrl ?
                        <img src={imageUrl} role="presentation" className="avatar" /> :
                        <Icon type="plus" className="avatar-uploader-trigger" />
                }
            </Upload>
        );
    }
};

class PicturesWall extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            previewVisible: false,
            propsbool: true,
            previewImage: '',
            fileList: [],
        }
    }
    handleCancel() {
        this.setState({ previewVisible: false })
    }
    handlePreview(file) {
        this.setState({
            previewImage: file.url || file.thumbUrl,
            previewVisible: true,
        });
    }

    handleChange(info) {
        let fileList = info.fileList;
        this.setState({ fileList });
        this.props.fileList(fileList);
    }
    componentWillReceiveProps(nextProps) {
        if (nextProps.lifePhotoList && this.state.propsbool) {
            this.state.fileList = nextProps.lifePhotoList;
            this.state.propsbool = false;
        }
    }
    render() {
        const { previewVisible, previewImage, fileList } = this.state;
        const uploadButton = (
            <div>
                <Icon type="plus" />
                <div className="ant-upload-text">Upload</div>
            </div>
        );
        return (
            <div className="clearfix">
                <Upload
                    action={globalConfig.context + "/api/user/avatar/upload"}
                    listType="picture-card"
                    fileList={fileList}
                    onPreview={this.handlePreview}
                    onChange={this.handleChange.bind(this)}
                >
                    {fileList.length >= 9 ? null : uploadButton}
                </Upload>
                <Modal visible={previewVisible} footer={null} onCancel={this.handleCancel}>
                    <img alt="example" style={{ width: '100%' }} src={previewImage} />
                </Modal>
            </div>
        );
    }
};

const PersonFrom = Form.create()(React.createClass({
    getData() {
        this.props.spinState(true);
        $.ajax({
            method: "get",
            dataType: "json",
            url: globalConfig.context + "/api/user/member",
            success: function (data) {

                if (data.data && data.data.info && data.data.pro) {
                    addressInit('cmbProvince', 'cmbCity', 'cmbArea',
                        data.data.locationProvince, data.data.locationCity, data.data.locationArea);
                    let theArr = splitUrl(data.data.info.publicityPictureUrl, ',', globalConfig.staticHost + '/upload');
                    this.setState({
                        idttType: data.data.info.identityType,
                        unitName: data.data.info.companyName,
                        unitNumber: data.data.info.unitSize,
                        unitIntro: data.data.info.companyIntroduction,
                        unitFrom: data.data.info.homeUnit,
                        publicityPictureUrl: data.data.info.publicityPictureUrl,
                        companyLifePicList: theArr,
                        qiyezizhi: data.data.pro.qualification,
                        turnover: data.data.pro.turnover,
                        schoolProp: data.data.pro.collegeAttribute,
                        schoolTime: data.data.pro.collegeEstablishTime,
                        aca: data.data.pro.academician,
                        PhDTutor: data.data.pro.doctoralTutor,
                        MSTutor: data.data.pro.masterTutor,
                        otherExperts: data.data.pro.otherExpert,
                        StateKeyLab: data.data.pro.nationalLab,
                        EduKeyLab: data.data.pro.educationLab,
                        ComCenter: data.data.pro.enterpriseCenter,
                        otherCenter: data.data.pro.otherCenter,
                        resTime: data.data.pro.institutionEstablishTime
                    });
                    this.idttTypeChange(data.data.info.identityType);
                };
            }.bind(this),
        }).always(function () {
            this.props.spinState(false);
        }.bind(this));
    },
    getInitialState() {
        return {
            loading: false,

            idttType: '企业',

            companyDis: 'block',
            schoolDis: 'none',
            resDis: 'none',
            companyLifePicObj: [],
            aca: 0,
            PhDTutor: 0,
            MSTutor: 0,
            otherExperts: 0,
            StateKeyLab: 0,
            EduKeyLab: 0,
            ComCenter: 0,
            otherCenter: 0
        };
    },
    handleSubmit(e) {
        e.preventDefault();
        this.props.form.validateFields((err, values) => {
            //地址值
            let cmbP = document.getElementById('cmbProvince').value;
            let cmbC = document.getElementById('cmbCity').value;
            let cmbA = document.getElementById('cmbArea').value;
            //
            let lifePhotoUrl = this.state.publicityPictureUrl;
            if (this.state.companyLifePicObj.length) {
                let leftPicArr = [];
                this.state.companyLifePicObj.map(function (item) {
                    leftPicArr.push(item.response.data);
                });
                lifePhotoUrl = leftPicArr.join(",");
            };
            if (!err) {
                this.props.spinState(true);

                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: globalConfig.context + "/api/user/orgPro",
                    data: {
                        "info.identityType": values.identityType,
                        "info.companyName": values.unitName,
                        "info.locationProvince": cmbP,
                        "info.locationCity": cmbC,
                        "info.locationArea": cmbA,
                        "info.unitSize": values.unitNumber,
                        "info.companyIntroduction": values.unitIntro,
                        "info.homeUnit": values.unitFrom,
                        "info.logoUrl": this.state.companyLogoUrl,
                        "info.publicityPictureUrl": lifePhotoUrl,
                        "pro.qualification": values.qiyezizhi,
                        "pro.turnover": values.turnover,
                        "pro.collegeAttribute": values.schoolProp,
                        "pro.collegeEstablishTime": values.schoolTime,
                        "pro.academician": values.aca,
                        "pro.doctoralTutor": values.PhDTutor,
                        "pro.masterTutor": values.MSTutor,
                        "pro.otherExpert": values.otherExperts,
                        "pro.nationalLab": values.StateKeyLab,
                        "pro.educationLab": values.EduKeyLab,
                        "pro.enterpriseCenter": values.ComCenter,
                        "pro.otherCenter": values.otherCenter,
                        "pro.institutionEstablishTime": values.resTime
                    }
                }).done(function (data) {
                    if (!data.error.length) {
                        message.success('保存成功！');
                    } else {
                        message.warning(data.error[0].message);
                    }
                }.bind(this)).always(function () {
                    this.props.spinState(false);
                }.bind(this));
            }
        });
    },
    idttTypeChange(e) {
        if (e === '企业') {
            this.props.form.setFieldsValue({ 'indentityType': e });
            this.setState({
                companyDis: 'block',
                schoolDis: 'none',
                resDis: 'none'
            });
        } else if (e === '院校') {
            this.props.form.setFieldsValue({ 'indentityType': e });
            this.setState({
                companyDis: 'none',
                schoolDis: 'block',
                resDis: 'none'
            });
        } else if (e === '研究机构') {
            this.props.form.setFieldsValue({ 'indentityType': e });
            this.setState({
                companyDis: 'none',
                schoolDis: 'none',
                resDis: 'block'
            });
        } else {
            this.props.form.setFieldsValue({ 'indentityType': e });
            this.setState({
                companyDis: 'none',
                schoolDis: 'none',
                resDis: 'none'
            });
        }
    },
    downloadPic(type) {
        window.open(globalConfig.context + "/open/downLoadPicture?path=" + type)
    },
    companyLogoUrl(e) {
        this.state.companyLogoUrl = e;
    },
    companyLifePicUrl(e) {
        this.state.companyLifePicObj = e;
    },
    componentDidMount() {
        addressInit('cmbProvince', 'cmbCity', 'cmbArea');
        this.getData();
    },
    render() {
        const FormItem = Form.Item;
        const Option = Select.Option;
        const { getFieldDecorator } = this.props.form;
        const formItemLayout = {
            labelCol: { span: 3 },
            wrapperCol: { span: 12 },
        };
        const _me = this;
        return (
            <Form horizontal onSubmit={this.handleSubmit} className="person-form">
                <FormItem
                    labelCol={{ span: 3 }}
                    wrapperCol={{ span: 8 }}
                    label="身份类型"
                >
                    {getFieldDecorator('identityType', {
                        initialValue: this.state.idttType
                    })(
                        <Select className="acc-edu-lvl" onChange={this.idttTypeChange}>
                            {
                                edulvlArr.map(function (item, i) {
                                    return <Option key={i} value={item} >{item}</Option>
                                })
                            }
                        </Select>
                        )}
                </FormItem>
                <FormItem
                    {...formItemLayout}
                    label="单位名称"
                >
                    {getFieldDecorator('unitName', {
                        initialValue: this.state.unitName
                    })(
                        <Input />
                        )}
                </FormItem>
                <FormItem
                    {...formItemLayout}
                    label="所在地"
                >
                    {getFieldDecorator('province')(
                        <div>
                            <select id="cmbProvince" name="cmbProvince"></select>
                            <select id="cmbCity" name="cmbCity"></select>
                            <select id="cmbArea" name="cmbArea"></select>
                        </div>
                    )}
                </FormItem>

                <FormItem
                    labelCol={{ span: 3 }}
                    wrapperCol={{ span: 20 }}
                    label="单位简介"
                >
                    {getFieldDecorator('unitIntro', {
                        initialValue: this.state.unitIntro
                    })(
                        <Input type="textarea"
                            placeholder="全面介绍自己，让商友更深入了解您，内容长度不超过1000个字。"
                            rows={6} />
                        )}
                    <p>还可输入{
                        (() => {
                            if (_me.props.form.getFieldValue('unitIntro') && _me.props.form.getFieldValue('unitIntro').length) {
                                return 1000 - _me.props.form.getFieldValue('unitIntro').length;
                            } else {
                                return 1000;
                            }
                        })()
                    }字/1000</p>
                </FormItem>

                <FormItem
                    {...formItemLayout}
                    label="归属单位"
                >
                    {getFieldDecorator('unitFrom', {
                        initialValue: this.state.unitFrom
                    })(
                        <Input placeholder="非法人单位填写。" />
                        )}
                </FormItem>
                <FormItem style={{ 'display': this.state.companyDis }}
                    labelCol={{ span: 3 }}
                    wrapperCol={{ span: 8 }}
                    label="企业资质"
                >
                    {getFieldDecorator('qiyezizhi', {
                        initialValue: this.state.qiyezizhi
                    })(
                        <Select className="acc-edu-lvl">
                            {
                                zizhiArr.map(function (item, i) {
                                    return <Option key={i} value={item} >{item}</Option>
                                })
                            }
                        </Select>
                        )}
                </FormItem>
                <FormItem style={{ 'display': this.state.schoolDis }}
                    labelCol={{ span: 3 }}
                    wrapperCol={{ span: 8 }}
                    label="院校属性"
                >
                    {getFieldDecorator('schoolProp', {
                        initialValue: this.state.schoolProp
                    })(
                        <Select className="acc-edu-lvl">
                            {
                                schoolArr.map(function (item, i) {
                                    return <Option key={i} value={item} >{item}</Option>
                                })
                            }
                        </Select>
                        )}
                </FormItem>
                <FormItem style={{ 'display': this.state.schoolDis }}
                    {...formItemLayout}
                    label="创办时间"
                >
                    {getFieldDecorator('schoolTime', {
                        initialValue: this.state.schoolTime || 0
                    })(
                        <InputNumber />
                        )}
                    <span>年</span>
                </FormItem>
                <div className="school-props clearfix" style={{ 'display': this.state.schoolDis }}>
                    <FormItem
                        labelCol={{ span: 10 }}
                        wrapperCol={{ span: 12 }}
                        label="院士"
                    >
                        {getFieldDecorator('aca', {
                            initialValue: this.state.aca || 0
                        })(
                            <InputNumber />
                            )}
                        <span>人</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 10 }}
                        wrapperCol={{ span: 12 }}
                        label="博士生导师"
                    >
                        {getFieldDecorator('PhDTutor', {
                            initialValue: this.state.PhDTutor || 0
                        })(
                            <InputNumber />
                            )}
                        <span>人</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 10 }}
                        wrapperCol={{ span: 12 }}
                        label="硕士生导师"
                    >
                        {getFieldDecorator('MSTutor', {
                            initialValue: this.state.MSTutor || 0
                        })(
                            <InputNumber />
                            )}
                        <span>人</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 10 }}
                        wrapperCol={{ span: 12 }}
                        label="其他专家"
                    >
                        {getFieldDecorator('otherExperts', {
                            initialValue: this.state.otherExperts || 0
                        })(
                            <InputNumber />
                            )}
                        <span>人</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 10 }}
                        wrapperCol={{ span: 12 }}
                        label="国家级重点实验室"
                    >
                        {getFieldDecorator('StateKeyLab', {
                            initialValue: this.state.StateKeyLab || 0
                        })(
                            <InputNumber />
                            )}
                        <span>所</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 10 }}
                        wrapperCol={{ span: 12 }}
                        label="教育部重点实验室"
                    >
                        {getFieldDecorator('EduKeyLab', {
                            initialValue: this.state.EduKeyLab || 0
                        })(
                            <InputNumber />
                            )}
                        <span>所</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 10 }}
                        wrapperCol={{ span: 12 }}
                        label="企业共建研究中心"
                    >
                        {getFieldDecorator('ComCenter', {
                            initialValue: this.state.ComCenter || 0
                        })(
                            <InputNumber />
                            )}
                        <span>所</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 10 }}
                        wrapperCol={{ span: 12 }}
                        label="其他研究中心"
                    >
                        {getFieldDecorator('otherCenter', {
                            initialValue: this.state.otherCenter || 0
                        })(
                            <InputNumber />
                            )}
                        <span>所</span>
                    </FormItem>
                </div>
                <FormItem style={{ 'display': this.state.resDis }}
                    {...formItemLayout}
                    label="创办时间"
                >
                    {getFieldDecorator('resTime', {
                        initialValue: this.state.resTime || 0
                    })(
                        <InputNumber />
                        )}
                    <span>年</span>
                </FormItem>
                <FormItem
                    {...formItemLayout}
                    label="LOGO"
                    labelCol={{ span: 3 }}
                    wrapperCol={{ span: 20 }}
                >
                    {getFieldDecorator('avatar')(
                        <Avatar name="companyLogo" urlData={this.companyLogoUrl} />
                    )}
                </FormItem>
                <div className="set-explain">
                    <p>上传的照片图片格式应为jpg格式，大小在2M以内</p>
                </div>
                <FormItem
                    labelCol={{ span: 3 }}
                    wrapperCol={{ span: 21 }}
                    label="宣传图片"
                >
                    {getFieldDecorator('companyLifePic')(
                        <PicturesWall fileList={this.companyLifePicUrl} lifePhotoList={this.state.companyLifePicList} />
                    )}
                </FormItem>
                <FormItem wrapperCol={{ span: 12, offset: 3 }}>
                    <Button className="set-submit" type="primary" htmlType="submit">保存</Button>
                </FormItem>
            </Form >
        );
    },
}));

const Person = React.createClass({
    getInitialState() {
        return {
            loading: false
        };
    },
    spinChange(e) {
        this.setState({
            loading: e
        });
    },
    render() {
        return (
            <Spin spinning={this.state.loading} className='spin-box'>
                <div className="set-person">
                    <div className="acc-detail">
                        <p className="acc-title">单位资料</p>
                        <PersonFrom spinState={this.spinChange} />
                    </div>
                </div>
            </Spin>
        )
    }
});

export default Person;