import React from 'react';
import { Icon, Modal, Button, Form, Upload, message, Input, Spin, Checkbox, Select } from 'antd';
import './comprehensive.less';
import ajax from 'jquery/src/ajax/xhr.js'
import $ from 'jquery/src/ajax';
import { getBase64, beforeUpload ,companySearch} from '../../../tools.js';

class Avatar extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            imageUrl: ''
        }
    }
    handleChange(info) {
        if (!this.props.oid || this.props.oid === "") {
            message.warning('请先选择公司！');
            return;
        };
        if (info.file.status === 'done') {
            // Get this url from response in real world.
            getBase64(info.file.originFileObj, imageUrl => this.setState({ imageUrl }));
            this.props.urlData(info.file.response.data);
        }
    }
    render() {
        const imageUrl = this.state.imageUrl;
        return (
            <Upload
                className="avatar-uploader"
                name="avatar"
                showUploadList={false}
                action={globalConfig.context + "/techservice/patent/patentFile"}
                data={{ 'sign': this.props.name, 'oid': this.props.oid }}
                beforeUpload={beforeUpload}
                onChange={this.handleChange.bind(this)}
            >
                {
                    imageUrl ?
                        <img src={imageUrl} role="presentation" className="avatar" /> :
                        <Icon type="plus" className="avatar-uploader-trigger" />
                }
            </Upload>
        );
    }
};

const PatentAddFrom = Form.create()(React.createClass({
    getCompanyList() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/techservice/patent/getUnitNames",
            success: function (data) {
                if (data.error.length || !data.data) {
                    return;
                };
                let _me = this;
                for (var item in data.data) {
                    _me.state.companyOption.push(
                        <Select.Option value={item} key={item}>{data.data[item]}</Select.Option>
                    )
                };
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            loading: false,
            companyOption: [],
            firstCheck: 0,
            secondCheck: 0,
            thirdCheck: 0

        };
    },
    componentWillMount() {
        this.getCompanyList();
    },
    handleSubmit(e) {
        e.preventDefault();
        if (!this.state.companyName || this.state.companyName === "") {
            message.warning('请先选择公司！');
            return;
        };
        this.props.form.validateFields((err, values) => {
            if (!err) {
                this.props.spinState(true);
                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: globalConfig.context + "/techservice/patent/manageApplyPatent",
                    data: {
                        'uid': this.state.companyName,
                        'firstInventorIdNumber': values.firstInventorID,
                        'firstInventorName': values.firstInventorName,
                        'patentDes': values.intro,
                        'secondInventorName': values.secondInventorName,
                        'thirdInventorName': values.thirdInventorName,
                        'firstInventorIsPublish': this.state.firstCheck,
                        'secondInventorIsPublish': this.state.secondCheck,
                        'thirdInventorIsPublish': this.state.thirdCheck,
                        'patentProryStatementUrl': this.state.avatarUrl
                    }
                }).done(function (data) {
                    if (!data.error.length) {
                        message.success('保存成功！');
                    } else {
                        message.warning(data.error[0].message);
                    }
                }.bind(this)).always(function () {
                    this.props.spinState(false);
                    this.props.clickOk();
                    this.props.form.resetFields();
                }.bind(this));
            }
        });
    },
    firstInventorCheck(e) {
        if (e.target.checked == true) {
            this.state.firstCheck = 1;
        } else if (e.target.checked == false) {
            this.state.firstCheck = 0;
        }
    },
    secondInventorCheck(e) {
        if (e.target.checked == true) {
            this.state.secondCheck = 1;
        } else if (e.target.checked == false) {
            this.state.secondCheck = 0;
        };
    },
    thirdInventorCheck(e) {
        if (e.target.checked == true) {
            this.state.thirdCheck = 1;
        } else if (e.target.checked == false) {
            this.state.thirdCheck = 0;
        };
    },
    avatarUrl(e) {
        this.state.avatarUrl = e;
    },
    render() {
        const FormItem = Form.Item;
        const { getFieldDecorator } = this.props.form;
        const formItemLayout = {
            labelCol: { span: 3 },
            wrapperCol: { span: 14 },
        };
        const _me = this;
        return (
            <Form horizontal onSubmit={this.handleSubmit} className="person-form">
                <Select placeholder="选择公司"
                    showSearch
                    filterOption={companySearch}
                    onChange={(e) => { this.state.companyName = e; }}
                    showSearch={true} style={{ width: 200 }} >{this.state.companyOption}</Select>
                <FormItem
                    labelCol={{ span: 24 }}
                    wrapperCol={{ span: 18 }}
                    label="专利简要描述"
                >
                    {getFieldDecorator('intro', {
                        initialValue: this.state.intro || null
                    })(
                        <Input type="textarea"
                            placeholder="多行输入"
                            rows={6} />
                        )}
                </FormItem>
                <p>第一发明人</p>
                <FormItem
                    {...formItemLayout}
                    label="姓名"
                >
                    {getFieldDecorator('firstInventorName', {
                        rules: [{ required: true, message: 'Please input name!' }]
                    })(
                        <Input className="mini-input" />
                        )}
                    <Checkbox onChange={this.firstInventorCheck}>告知专利局是否公布</Checkbox>
                </FormItem>
                <FormItem
                    {...formItemLayout}
                    label="身份证"
                >
                    {getFieldDecorator('firstInventorID', {
                        rules: [{ required: true, message: 'Please input ID!' }]
                    })(
                        <Input className="mini-input" />
                        )}
                </FormItem>
                <p>第二发明人</p>
                <FormItem
                    {...formItemLayout}
                    label="姓名"
                >
                    {getFieldDecorator('secondInventorName')(
                        <Input className="mini-input" />
                    )}
                    <Checkbox onChange={this.secondInventorCheck}>告知专利局是否公布</Checkbox>
                </FormItem>
                <p>第三发明人</p>
                <FormItem
                    {...formItemLayout}
                    label="姓名"
                >
                    {getFieldDecorator('thirdInventorName')(
                        <Input className="mini-input" />
                    )}
                    <Checkbox onChange={this.thirdInventorCheck}>告知专利局是否公布</Checkbox>
                </FormItem>
                <FormItem
                    {...formItemLayout}
                    label="上传代理委托书"
                    labelCol={{ span: 24 }}
                    wrapperCol={{ span: 12 }}
                >
                    {getFieldDecorator('avatar')(
                        <Avatar urlData={this.avatarUrl} name='patent_prory_statement' oid={this.state.companyName} />
                    )}
                    <span>请上传专利代理委托书</span><a onClick={() => { window.open(globalConfig.context + "/open/downloadTemplateFile?sign=patent_prory_statement") }}>模板下载</a>
                </FormItem>
                <FormItem>
                    <Button className="set-submit" type="primary" htmlType="submit">保存</Button>
                    <Button type="ghost" style={{ marginLeft: '20px' }} onClick={this.props.closeModal}>取消</Button>
                </FormItem>
            </Form >
        );
    },
}));


const PatentAdd = React.createClass({
    getInitialState() {
        return {
            visible: false,
            loading: false
        };
    },
    showModal() {
        this.setState({
            visible: true,
        });
    },
    handleOk() {
        this.setState({
            visible: false,
        });
    },
    handleCancel(e) {
        this.setState({
            visible: false,
        });
        this.props.closeDesc(false);
    },
    spinChange(e) {
        this.setState({
            loading: e
        });
    },
    render() {
        return (
            <div className="patent-addNew">
                <Button className="patent-addNew" type="primary" onClick={this.showModal}>申请新专利<Icon type="plus" /></Button>
                <Spin spinning={this.state.loading} className='spin-box'>
                    <Modal title="新专利申请" visible={this.state.visible}
                        onOk={this.handleOk} onCancel={this.handleCancel}
                        width='800px'
                        footer=''
                    >
                        <PatentAddFrom spinState={this.spinChange} closeModal={this.handleCancel}  clickOk={this.handleOk} />
                    </Modal>
                </Spin>
            </div>
        );
    },
});
export default PatentAdd;